function spirala_vstup(z,k,p)
% prostorová køivka s parametrickými rovnicemi x=t.*sin(t),y=t.*cos(t),z=t
% vykreslená pomocí pøíkazu plot3
    % hlavièka funkce je ve tvaru function nazev(vstup1,vstup2, vstup3)
	% funkce se vstupními parametry z,k,p
    % z - zaèátek intervalu (vektoru t)
    % k - konec intervalu (vektoru t)
    % p - pocet bodu ve vektoru t
%-------------------------------------------------------------------------
% funkce spirala_vstup(z,k,p) musí být volana z pøíkazového øádku MATLABu
% svým názvem a parametry v kulatých závorkách:
% napø. spirala_vstup(0,50,200); spirala_vstup(-8*pi,8*pi,500)
% nebo a=0; b=90; c=300; spirala_vstup(a,b,c) apod.
%-------------------------------------------------------------------------

t=linspace(z,k,p); % t v intervalu od "z" do "k" s "p" body

% parametrické rovnice køivky: x=t.*sin(t), y=t.*cos(t), z=t
x=t.*sin(t);
y=t.*cos(t);
z=t;

plot3(x,y,z,'g','LineWidth',3) % vykreslení køivky v prostoru
                % zvolena barva g - zelená (green)
                % zvolena tlouš�ka èáry ('LineWidth') - 3
xlabel('x') % popis osy x
ylabel('y') % popis osy y
zlabel('z') % popis osy z                